pub enum INonceErrors {
ProtocolNonceNotSupported(ProtocolNonceNotSupported),
InvalidNonceKey(InvalidNonceKey),
NonceOverflow(NonceOverflow),
ExpiringNonceReplay(ExpiringNonceReplay),
ExpiringNonceSetFull(ExpiringNonceSetFull),
InvalidExpiringNonceExpiry(InvalidExpiringNonceExpiry),
}Expand description
Container for all the INonce custom errors.
Variants
ProtocolNonceNotSupported(ProtocolNonceNotSupported)
InvalidNonceKey(InvalidNonceKey)
NonceOverflow(NonceOverflow)
ExpiringNonceReplay(ExpiringNonceReplay)
ExpiringNonceSetFull(ExpiringNonceSetFull)
InvalidExpiringNonceExpiry(InvalidExpiringNonceExpiry)
Implementations
Sourceimpl INonceErrors
impl INonceErrors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl NonceError
impl NonceError
Sourcepub const fn protocol_nonce_not_supported() -> Self
pub const fn protocol_nonce_not_supported() -> Self
Creates an error for protocol nonce not supported
Sourcepub const fn invalid_nonce_key() -> Self
pub const fn invalid_nonce_key() -> Self
Creates an error for invalid nonce key
Sourcepub const fn nonce_overflow() -> Self
pub const fn nonce_overflow() -> Self
Creates an error for when nonce overflows
Sourcepub const fn expiring_nonce_replay() -> Self
pub const fn expiring_nonce_replay() -> Self
Creates an error for expiring nonce replay
Sourcepub const fn expiring_nonce_set_full() -> Self
pub const fn expiring_nonce_set_full() -> Self
Creates an error for expiring nonce set being full
Sourcepub const fn invalid_expiring_nonce_expiry() -> Self
pub const fn invalid_expiring_nonce_expiry() -> Self
Creates an error for invalid expiring nonce expiry